<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hi">
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>Unable to get exclusive lock</source>
        <translation>अनन्य लॉक प्राप्त करने में असमर्थ</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="54"/>
        <source>Another package management application (like Synaptic or apt-get), is already running. Please close that application first</source>
        <translation>एक अन्य पैकेज प्रबंधन अनुप्रयोग (जैसे सिनैप्टिक या apt-get), पहले से ही चल रहा है। कृपया उस अनुप्रयोग को पहले बंद करें</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="67"/>
        <source>You must run this program as root.</source>
        <translation>इस प्रोग्राम को चलाने हेतु आपका रुट होना आवश्यक है।</translation>
    </message>
</context>
<context>
    <name>mxcodecs</name>
    <message>
        <location filename="../mxcodecs.ui" line="14"/>
        <source>MX Codecs Installer</source>
        <translation>MX कोडेक्स इंस्टॉलर</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="27"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;justify&quot;&gt;This application allows you to install restricted codecs that permit advanced video and audio functions.&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;In some juridictions their distribution may be limited so the user must meet local regulations. &lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;br/&gt;&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Do you assume legal responsibility for downloading these codecs?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;justify&quot;&gt;इस अनुप्रयोग द्वारा आप प्रतिबंधित कोडेक्स इंस्टॉल कर सकते हैं, जो उन्नत ऑडियो व वीडियो कार्यों हेतु सहायक होते हैं।&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;कुछ न्यायिक अधिकार क्षेत्रों में इनका वितरण उपयोक्ता के स्थानीय कानूनी नियमों की पूर्ति हेतु सीमित हो सकता है।&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;br/&gt;&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;क्या आप इन कोडेक्स को डाउनलोड करने की कानूनी नियमानुसार ज़िम्मेदारी लेते हैं?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="44"/>
        <source>Downloading codecs files</source>
        <translation>कोडेक्स फ़ाइलें डाउनलोड हो रही हैं</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="94"/>
        <source>Cancel any changes then quit</source>
        <translation>बदलाव रद्द कर बंद करें</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="97"/>
        <location filename="../mxcodecs.cpp" line="267"/>
        <source>Cancel</source>
        <translation>रद्द</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="105"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="118"/>
        <source>Apply any changes then quit</source>
        <translation>बदलाव लागू कर बंद करें</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="121"/>
        <source>OK</source>
        <translation>ओ.के.</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="177"/>
        <source>About this application</source>
        <translation>इस अनुप्रयोग के बारे में</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="180"/>
        <source>About...</source>
        <translation>बारे में...</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="188"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="217"/>
        <source>Display help </source>
        <translation>मदद देखें</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="220"/>
        <source>Help</source>
        <translation>सहायता</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="228"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="104"/>
        <location filename="../mxcodecs.cpp" line="111"/>
        <location filename="../mxcodecs.cpp" line="119"/>
        <location filename="../mxcodecs.cpp" line="127"/>
        <location filename="../mxcodecs.cpp" line="136"/>
        <location filename="../mxcodecs.cpp" line="143"/>
        <location filename="../mxcodecs.cpp" line="152"/>
        <location filename="../mxcodecs.cpp" line="160"/>
        <source>&lt;b&gt;Running command...&lt;/b&gt;&lt;p&gt;</source>
        <translation>&lt;b&gt;कमांड निष्पादित की जा रही है...&lt;/b&gt;&lt;p&gt;</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="107"/>
        <location filename="../mxcodecs.cpp" line="123"/>
        <location filename="../mxcodecs.cpp" line="130"/>
        <location filename="../mxcodecs.cpp" line="139"/>
        <location filename="../mxcodecs.cpp" line="145"/>
        <location filename="../mxcodecs.cpp" line="156"/>
        <location filename="../mxcodecs.cpp" line="163"/>
        <location filename="../mxcodecs.cpp" line="192"/>
        <location filename="../mxcodecs.cpp" line="245"/>
        <source>Error</source>
        <translation>त्रुटि</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="108"/>
        <location filename="../mxcodecs.cpp" line="124"/>
        <location filename="../mxcodecs.cpp" line="140"/>
        <location filename="../mxcodecs.cpp" line="157"/>
        <source>Cannot connect to the download site</source>
        <translation>डाउनलोड साइट से जुड़ा नहीं जा सका</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="114"/>
        <location filename="../mxcodecs.cpp" line="131"/>
        <location filename="../mxcodecs.cpp" line="146"/>
        <location filename="../mxcodecs.cpp" line="164"/>
        <source>Error downloading %1</source>
        <translation>%1 डाउनलोड करने में त्रुटि</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="169"/>
        <source>&lt;b&gt;Download Finished.&lt;/b&gt;</source>
        <translation>&lt;b&gt;डाउनलोड पूर्ण हुआ।&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="188"/>
        <source>Installing downloaded files</source>
        <translation>डाउनलोड की गई फ़ाइलें इंस्टॉल हो रही हैं</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="193"/>
        <source>No downloaded *.debs files found.</source>
        <translation>डाउनलोड की गई कोई *.deb फ़ाइलें नहीं मिली।</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="206"/>
        <source>&lt;b&gt;Installing...&lt;/b&gt;&lt;p&gt;</source>
        <translation>&lt;b&gt;इंस्टॉल हो रहा है...&lt;/b&gt;&lt;p&gt;</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="219"/>
        <source>Error installing %1</source>
        <translation>%1 इंस्टॉल करने में त्रुटि</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="223"/>
        <source>Fix missing dependencies...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="225"/>
        <source>Error running %1 command</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="237"/>
        <source>&lt;b&gt;Installation process has finished&lt;/b&gt;</source>
        <translation>&lt;b&gt;इंस्टॉल प्रक्रिया पूर्ण हुई&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="241"/>
        <source>Finished</source>
        <translation>पूर्ण हुआ</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="242"/>
        <source>Codecs files have been downloaded and installed successfully.</source>
        <translation>कोडेक्स फ़ाइलें डाउनलोड कर सफलतापूर्वक डाउनलोड हो गई हैं।</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="246"/>
        <source>Process finished. Errors have occurred during the installation.</source>
        <translation>प्रक्रिया पूर्ण हुई। इंस्टॉल के दौरान त्रुटियाँ हुई हैं।</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="260"/>
        <source>About MX Codecs</source>
        <translation>MX कोडेक्स के बारे में</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="261"/>
        <source>MX Codecs</source>
        <translation>MX कोडेक्स</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="261"/>
        <source>Version: </source>
        <translation>संस्करण :</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="263"/>
        <source>Simple codecs downloader for MX Linux</source>
        <translation>MX लिनक्स हेतु सरल कोडेक्स डाउनलोड साधन</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="264"/>
        <source>Copyright (c) MX Linux</source>
        <translation>प्रतिलिप्याधिकार (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="265"/>
        <source>License</source>
        <translation>लाइसेंस</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="266"/>
        <location filename="../mxcodecs.cpp" line="276"/>
        <source>Changelog</source>
        <translation>परिवर्तन सूची</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="283"/>
        <source>&amp;Close</source>
        <translation>&amp;बंद करें</translation>
    </message>
</context>
</TS>
